@@ -18,7 +18,7 @@ purpose_list = ['아침식사', '점심식사', '저녁식사', '식사모임',
 
 
 class StoreMixin:
-    def get_stores(self, keyword: str, page_no: int, page_size: int = 20, proxy=None):
+    def get_stores(self, keyword: str, page_no: int, page_size: int = 20, proxies=None):
 
         headers = {
             'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/119.0.0.0 Safari/537.36',
@@ -47,7 +47,7 @@ class StoreMixin:
                                  headers=headers,
                                  data=data,
                                  allow_redirects=False,
-                                 proxies=proxy)
+                                 proxies=proxies)
         response.raise_for_status()
         response_data = response.json()
         stores = response_data['result_data']['poi_section']['list']
@@ -241,10 +241,10 @@ class StoreMixin:
 
         return banner_urls
 
-    def get_store(self, code: str, proxy: None):
+    def get_store(self, code: str, proxies: None):
         response = requests.post(f'https://www.diningcode.com/profile.php?rid={code}',
                                  headers=HEADERS,
-                                 proxies=proxy
+                                 proxies=proxies
                                  )
         soup = BeautifulSoup(response.text, 'html.parser')
         store_name = soup.find('div', class_='tit-point').get_text().replace('\n', '')
